@@ -1,15 +1,19 @@
-from netbox.api import OrderedDefaultRouter
+from netbox.api.routers import NetBoxRouter
+
 from netbox_dns.api.views import (
     NetboxDNSRootView,
+    ViewViewSet,
     ZoneViewSet,
     NameServerViewSet,
     RecordViewSet,
 )
 
-router = OrderedDefaultRouter()
+router = NetBoxRouter()
 router.APIRootView = NetboxDNSRootView
 
+router.register("views", ViewViewSet)
 router.register("zones", ZoneViewSet)
 router.register("nameservers", NameServerViewSet)
 router.register("records", RecordViewSet)
+
 urlpatterns = router.urls
