@@ -3,15 +3,16 @@ from rest_framework.decorators import action
 from rest_framework.response import Response
 from rest_framework.routers import APIRootView
 
-from netbox.api.views import ModelViewSet
+from netbox.api.viewsets import NetBoxModelViewSet
 
 from netbox_dns.api.serializers import (
+    ViewSerializer,
     ZoneSerializer,
     NameServerSerializer,
     RecordSerializer,
 )
-from netbox_dns.filters import ZoneFilter, NameServerFilter, RecordFilter
-from netbox_dns.models import Zone, NameServer, Record
+from netbox_dns.filters import ViewFilter, ZoneFilter, NameServerFilter, RecordFilter
+from netbox_dns.models import View, Zone, NameServer, Record
 
 
 class NetboxDNSRootView(APIRootView):
@@ -23,8 +24,22 @@ class NetboxDNSRootView(APIRootView):
         return "NetboxDNS"
 
 
-class ZoneViewSet(ModelViewSet):
-    queryset = Zone.objects.all()
+class ViewViewSet(NetBoxModelViewSet):
+    queryset = View.objects.all()
+    serializer_class = ViewSerializer
+    filterset_class = ViewFilter
+
+    @action(detail=True, methods=["get"])
+    def views(self, request, pk=None):
+        views = View.objects.filter(zone=pk)
+        serializer = ViewSerializer(views, many=True, context={"request": request})
+        return Response(serializer.data)
+
+
+class ZoneViewSet(NetBoxModelViewSet):
+    queryset = Zone.objects.all().prefetch_related(
+        "view", "nameservers", "tags", "soa_mname", "record_set"
+    )
     serializer_class = ZoneSerializer
     filterset_class = ZoneFilter
 
@@ -43,8 +58,8 @@ class ZoneViewSet(ModelViewSet):
         return Response(serializer.data)
 
 
-class NameServerViewSet(ModelViewSet):
-    queryset = NameServer.objects.all()
+class NameServerViewSet(NetBoxModelViewSet):
+    queryset = NameServer.objects.all().prefetch_related("zones")
     serializer_class = NameServerSerializer
     filterset_class = NameServerFilter
 
@@ -55,8 +70,8 @@ class NameServerViewSet(ModelViewSet):
         return Response(serializer.data)
 
 
-class RecordViewSet(ModelViewSet):
-    queryset = Record.objects.all()
+class RecordViewSet(NetBoxModelViewSet):
+    queryset = Record.objects.all().prefetch_related("zone", "zone__view")
     serializer_class = RecordSerializer
     filterset_class = RecordFilter
 
